[English](README.en.md)

## Рекомендации по настройке разработки

### Как начать

Используйте `bun i`, `npm i`, `pnpm i` или `yarn`, чтобы установить пакеты.

### Настройка переменных

- Используйте файл `.env` для настройки переменных собственной среды разработки.
- Переменные окружения с префиксом `PUBLIC_` широко используются в `/src/utils/config.ts`.

### Полезные команды

Запуск проверки соответствия типов и автоматически исправить ошибки стилей, порядок импорта, форматирование:

```
bun run typecheck
bun run fix
```


## End-to-End (E2E) тесты

End-to-end тесты написаны с использованием [Playwright](https://playwright.dev/).

### Структура

- `/tests/*`: содержит файлы тестов
- `/playwright.config.ts`: конфиг для Playwright

### Начало работы

Следуйте этим шагам:

1. **Установите зависимости**: Запустите `npm run e2e:install`, чтобы установить необходимые зависимости для выполнения тестов.

2. **Запустите тесты**: После установки зависимостей используйте `npm run e2e:tests`.

### Дополнительная информация

Для параллельного исполнения:
- `npx playwright test --project=webkit --workers 4`

Для получения дополнительной информации о написании тестов с использованием Playwright - [Документация Playwright](https://playwright.dev/docs/intro).

### 🚀 Тесты в режиме CI

Тесты выполняются в рамках GitHub workflow. Мы организуем наши тесты в две основные директории:

- `tests`: Содержит тесты, которые не требуют аутентификации.
- `tests-with-auth`: Содержит тесты, которые взаимодействуют с аутентифицированными частями приложения.

🔧 **Конфигурация:**

Playwright настроен на использование переменной окружения `BASE_URL`. Убедитесь, что она правильно установлена в вашей конфигурации CI для указания на правильную среду.

📝 **Примечание:**

После того как страницы были настроены для работы с аутентификацией, все тесты должны быть перемещены в директорию `tests` для упрощения процесса тестирования.
